@@ -8,8 +8,28 @@ from botx.clients.clients.sync_client import Client
 from botx.collecting.collectors.collector import Collector
 from botx.dependencies.injection_params import Depends
 from botx.exceptions import BotXAPIError, DependencyFailure, ServerUnknownError
+from botx.models.attachments import (
+    AttachList,
+    Attachment,
+    Contact,
+    Document,
+    Image,
+    Link,
+    Location,
+    Video,
+    Voice,
+)
 from botx.models.buttons import BubbleElement, KeyboardElement
 from botx.models.credentials import ExpressServer, ServerCredentials
+from botx.models.entities import (
+    ChatMention,
+    Entity,
+    EntityList,
+    Forward,
+    Mention,
+    Reply,
+    UserMention,
+)
 from botx.models.enums import (
     ChatTypes,
     CommandTypes,
@@ -22,16 +42,15 @@ from botx.models.enums import (
 from botx.models.errors import BotDisabledErrorData, BotDisabledResponse
 from botx.models.events import ChatCreatedEvent
 from botx.models.files import File
-from botx.models.forwards import Forward
-from botx.models.mentions import ChatMention, Mention, UserMention
 from botx.models.menu import Status
-from botx.models.messages.incoming_message import Entity, IncomingMessage
+from botx.models.messages.incoming_message import IncomingMessage
 from botx.models.messages.message import Message
 from botx.models.messages.sending.credentials import SendingCredentials
 from botx.models.messages.sending.markup import MessageMarkup
 from botx.models.messages.sending.message import SendingMessage
 from botx.models.messages.sending.options import MessageOptions, NotificationOptions
 from botx.models.messages.sending.payload import MessagePayload, UpdatePayload
+from botx.models.status import StatusRecipient
 from botx.testing.building.builder import MessageBuilder
 
 try:
@@ -75,19 +94,32 @@ __all__ = (
     "ChatCreatedEvent",
     # files
     "File",
+    # attachments
+    "Image",
+    "Video",
+    "Document",
+    "Voice",
+    "Location",
+    "Contact",
+    "Link",
+    "Attachment",
+    "AttachList",
     # mentions
     "Mention",
     "ChatMention",
     "UserMention",
     # status
     "Status",
+    "StatusRecipient",
     # messages
     # handler message
     "Message",
     # incoming
     "IncomingMessage",
     "Entity",
+    "EntityList",
     "Forward",
+    "Reply",
     # sending
     "SendingCredentials",
     "SendingMessage",
